Index: chrome/browser/browser.cc |
diff --git a/chrome/browser/browser.cc b/chrome/browser/browser.cc |
index 252ed9fd1be8c17300722fce1ff3a8fa6fbe87e4..5d3aa0e47f44b4ed01e522e9bfd833ec7b0e137b 100644 |
--- a/chrome/browser/browser.cc |
+++ b/chrome/browser/browser.cc |
@@ -431,12 +431,12 @@ SkBitmap Browser::GetCurrentPageIcon() const { |
return contents ? contents->GetFavIcon() : SkBitmap(); |
} |
-string16 Browser::GetCurrentPageTitle() const { |
+string16 Browser::GetWindowTitleForCurrentTab() const { |
TabContents* contents = tabstrip_model_.GetSelectedTabContents(); |
string16 title; |
// |contents| can be NULL because GetCurrentPageTitle is called by the window |
// during the window's creation (before tabs have been added). |
if (contents) { |
title = contents->GetTitle(); |
FormatTitleForDisplay(&title); |
@@ -431,12 +431,12 @@ SkBitmap Browser::GetCurrentPageIcon() const { |
TabContents* contents = tabstrip_model_.GetSelectedTabContents(); |
string16 title; |
- // |contents| can be NULL because GetCurrentPageTitle is called by the window |
- // during the window's creation (before tabs have been added). |
+ // |contents| can be NULL because GetWindowTitleForCurrentTab is called by the |
+ // window during the window's creation (before tabs have been added). |
if (contents) { |
title = contents->GetTitle(); |